'''

MIT License

Copyright (c) 2023 Fast Data Science Ltd (https://fastdatascience.com)

Maintainer: Thomas Wood

Tutorial at https://fastdatascience.com/drug-named-entity-recognition-python-library/

Permission is hereby granted, free of charge, to any person obtaining a copy
of this software and associated documentation files (the "Software"), to deal
in the Software without restriction, including without limitation the rights
to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
copies of the Software, and to permit persons to whom the Software is
furnished to do so, subject to the following conditions:

The above copyright notice and this permission notice shall be included in all
copies or substantial portions of the Software.

THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
SOFTWARE.

'''

stopwords = {'abbott',
             'abello',
             'about',
             'above',
             'across',
             'actelion',
             'aesica',
             'afghanistan',
             'africa',
             'african',
             'after',
             'afterwards',
             'again',
             'against',
             'aient',
             'aies',
             'albania',
             'alcon',
             'algeria',
             'allergan',
             'almost',
             'almus',
             'alone',
             'along',
             'alpharma',
             'already',
             'also',
             'altana',
             'although',
             'always',
             'american',
             'amgen',
             'among',
             'amongst',
             'amount',
             'andorra',
             'angola',
             'anguilla',
             'another',
             'antarctica',
             'antigua',
             'anyhow',
             'anyone',
             'anything',
             'anyway',
             'anywhere',
             'april',
             'arab',
             'arabia',
             'aren',
             'argentina',
             'armenia',
             'around',
             'aruba',
             'ascension',
             'assertio',
             'astrazeneca',
             'august',
             'aura',
             'aurai',
             'auraient',
             'aurais',
             'aurait',
             'auras',
             'aurez',
             'auriez',
             'aurions',
             'aurons',
             'auront',
             'australia',
             'austria',
             'avaient',
             'avais',
             'avait',
             'avec',
             'aventis',
             'avez',
             'aviez',
             'avions',
             'avons',
             'ayant',
             'ayante',
             'ayantes',
             'ayants',
             'ayez',
             'ayons',
             'azerbaijan',
             'back',
             'bahamas',
             'bahrain',
             'bangladesh',
             'barbados',
             'barbuda',
             'bausch',
             'baxter',
             'bayer',
             'became',
             'because',
             'become',
             'becomes',
             'becoming',
             'becton',
             'been',
             'before',
             'beforehand',
             'behind',
             'beiersdorf',
             'being',
             'belarus',
             'belgium',
             'belize',
             'below',
             'benckiser',
             'benin',
             'berk',
             'bermuda',
             'beside',
             'besides',
             'between',
             'beyond',
             'bhutan',
             'biogen',
             'bioscience',
             'bissau',
             'boehringer',
             'bolivarian',
             'bolivia',
             'bonaire',
             'boots',
             'bosnia',
             'both',
             'botswana',
             'bottom',
             'bouvet',
             'braun',
             'brazil',
             'bristol',
             'british',
             'brunei',
             'bulgaria',
             'burkina',
             'burundi',
             'cabo',
             'caicos',
             'caledonia',
             'call',
             'cambodia',
             'cameroon',
             'canada',
             'cannot',
             'cayman',
             'celltech',
             'central',
             'cephalon',
             'chad',
             'chemidex',
             'chiesi',
             'chile',
             'china',
             'christmas',
             'chugai',
             'cilag',
             'city',
             'clinical',
             'cocos',
             'colgate',
             'colombia',
             'coloplast',
             'comoros',
             'congo',
             'consumer',
             'convatec',
             'cook',
             'copyright',
             'costa',
             'could',
             'couldn',
             'croatia',
             'crookes',
             'cuba',
             'cunha',
             'cyprus',
             'czechia',
             'dans',
             'darussalam',
             'date',
             'davis',
             'december',
             'democratic',
             'denmark',
             'dentsply',
             'diagnostics',
             'dickinson',
             'didn',
             'dista',
             'djibouti',
             'does',
             'doesn',
             'doing',
             'dominica',
             'dominican',
             'done',
             'down',
             'dupont',
             'during',
             'dutch',
             'each',
             'ecuador',
             'egypt',
             'eight',
             'eisai',
             'either',
             'eleven',
             'elle',
             'else',
             'elsewhere',
             'emirates',
             'empty',
             'enough',
             'equatorial',
             'eritrea',
             'estonia',
             'eswatini',
             'ethicon',
             'ethiopia',
             'eudract',
             'eues',
             'eurent',
             'eusse',
             'eussent',
             'eusses',
             'eussiez',
             'eussions',
             'eustatius',
             'even',
             'ever',
             'every',
             'everyone',
             'everything',
             'everywhere',
             'except',
             'fabre',
             'falkland',
             'faroe',
             'faso',
             'february',
             'federated',
             'federation',
             'ferring',
             'fifteen',
             'fifty',
             'fiji',
             'finland',
             'first',
             'five',
             'florizel',
             'former',
             'formerly',
             'forty',
             'four',
             'france',
             'french',
             'fresenius',
             'friday',
             'from',
             'front',
             'full',
             'furent',
             'further',
             'fusse',
             'fussent',
             'fusses',
             'fussiez',
             'fussions',
             'futuna',
             'gabon',
             'galderma',
             'galpharm',
             'gambia',
             'gamble',
             'garnier',
             'gate',
             'georgia',
             'germany',
             'ghana',
             'gibraltar',
             'gilead',
             'give',
             'glaxosmithkline',
             'gotten',
             'greece',
             'greenland',
             'grenada',
             'grenadines',
             'grifols',
             'guadeloupe',
             'guam',
             'guatemala',
             'guernsey',
             'guiana',
             'guinea',
             'guyana',
             'hadn',
             'haiti',
             'hakko',
             'hasn',
             'have',
             'haven',
             'having',
             'health',
             'healthcare',
             'heard',
             'heinz',
             'helena',
             'hence',
             'here',
             'hereafter',
             'hereby',
             'herein',
             'hereupon',
             'hers',
             'herself',
             'herzegovina',
             'hillcross',
             'himself',
             'hoechst',
             'holy',
             'honduras',
             'hong',
             'however',
             'http',
             'https',
             'hundred',
             'hungary',
             'iceland',
             'indeed',
             'india',
             'indian',
             'indonesia',
             'ingelheim',
             'into',
             'invicta',
             'ipsen',
             'iran',
             'iraq',
             'ireland',
             'islamic',
             'island',
             'islands',
             'isle',
             'israel',
             'italy',
             'itself',
             'ivax',
             'jamaica',
             'janssen',
             'january',
             'japan',
             'jersey',
             'jordan',
             'july',
             'june',
             'just',
             'kazakhstan',
             'keeling',
             'keep',
             'kenya',
             'king',
             'kingdom',
             'kiribati',
             'kitts',
             'kong',
             'korea',
             'kuwait',
             'kyowa',
             'kyrgyzstan',
             'lambert',
             'lanka',
             'last',
             'latter',
             'latterly',
             'latvia',
             'least',
             'lebanon',
             'lederie',
             'leone',
             'lesotho',
             'less',
             'leste',
             'leur',
             'liberia',
             'libya',
             'liechtenstein',
             'lifescan',
             'lilly',
             'lithuania',
             'lomb',
             'lucia',
             'lundbeck',
             'luxembourg',
             'maarten',
             'macao',
             'macedonia',
             'madagascar',
             'made',
             'mais',
             'make',
             'malawi',
             'malaysia',
             'maldives',
             'mali',
             'malta',
             'malvinas',
             'many',
             'march',
             'mariana',
             'marino',
             'marion',
             'marshall',
             'martin',
             'martindale',
             'martinique',
             'mauritania',
             'mauritius',
             'mayen',
             'mayne',
             'mayotte',
             'mcdonald',
             'mcneil',
             'meanwhile',
             'meda',
             'medac',
             'medical',
             'medisense',
             'menarini',
             'merck',
             'mexico',
             'micronesia',
             'might',
             'mightn',
             'milupa',
             'mine',
             'minor',
             'miquelon',
             'moldova',
             'monaco',
             'monday',
             'mongolia',
             'montenegro',
             'montserrat',
             'more',
             'moreover',
             'morocco',
             'most',
             'mostly',
             'move',
             'mozambique',
             'much',
             'must',
             'mustn',
             'myanmar',
             'myers',
             'myself',
             'name',
             'namely',
             'namibia',
             'nauru',
             'needn',
             'neither',
             'nepal',
             'netherlands',
             'neutrogena',
             'never',
             'nevertheless',
             'nevis',
             'next',
             'nicaragua',
             'niger',
             'nigeria',
             'nine',
             'niue',
             'nobody',
             'none',
             'noone',
             'nordisk',
             'norfolk',
             'north',
             'northern',
             'norway',
             'nothing',
             'notre',
             'nous',
             'novartis',
             'november',
             'novo',
             'nowhere',
             'nutrition',
             'nycomed',
             'oasteur',
             'ocean',
             'octapharma',
             'october',
             'often',
             'oman',
             'once',
             'only',
             'onto',
             'orion',
             'other',
             'others',
             'otherwise',
             'otsuka',
             'ours',
             'ourselves',
             'outlying',
             'over',
             'page',
             'pakistan',
             'palau',
             'palestine',
             'palmolive',
             'panama',
             'papua',
             'paraguay',
             'parke',
             'part',
             'path',
             'people',
             'perhaps',
             'peru',
             'pfizer',
             'pharm',
             'pharma',
             'pharmaceuticals',
             'pharmacia',
             'philippines',
             'pierre',
             'pitcairn',
             'please',
             'plough',
             'plurinational',
             'poland',
             'polynesia',
             'portugal',
             'poulenc',
             'pour',
             'principe',
             'procter',
             'products',
             'proprietary',
             'province',
             'pubmed',
             'puerto',
             'qatar',
             'quite',
             'rather',
             'really',
             'reckitt',
             'regarding',
             'reproduction',
             'republic',
             'reserved',
             'revision',
             'rica',
             'rico',
             'roche',
             'romania',
             'rosemont',
             'ross',
             'roussel',
             'russian',
             'rwanda',
             'rybar',
             'saba',
             'sahara',
             'saint',
             'salts',
             'salvador',
             'same',
             'samoa',
             'sandoz',
             'sandwich',
             'sankyo',
             'sanofi',
             'saturday',
             'saudi',
             'schering',
             'schwarz',
             'searle',
             'seem',
             'seemed',
             'seeming',
             'seems',
             'senegal',
             'september',
             'sera',
             'serai',
             'seraient',
             'serais',
             'serait',
             'seras',
             'serbia',
             'serez',
             'seriez',
             'serions',
             'serious',
             'serono',
             'serons',
             'seront',
             'servier',
             'several',
             'seychelles',
             'shan',
             'shire',
             'should',
             'shouldn',
             'show',
             'side',
             'sierra',
             'sigma',
             'since',
             'singapore',
             'sint',
             'sixty',
             'slovakia',
             'slovenia',
             'snbts',
             'soient',
             'sois',
             'soit',
             'solomon',
             'solvay',
             'somalia',
             'some',
             'somehow',
             'someone',
             'something',
             'sometime',
             'sometimes',
             'somewhere',
             'sommes',
             'sont',
             'south',
             'southern',
             'soyez',
             'soyons',
             'spain',
             'squibb',
             'state',
             'states',
             'stiefel',
             'still',
             'strain',
             'strains',
             'strictly',
             'such',
             'sudan',
             'suis',
             'sunday',
             'suriname',
             'svalbard',
             'sweden',
             'switzerland',
             'syrian',
             'taiwan',
             'tajikistan',
             'take',
             'takeda',
             'tanzania',
             'taro',
             'territories',
             'territory',
             'teva',
             'thailand',
             'than',
             'that',
             'their',
             'theirs',
             'them',
             'themselves',
             'then',
             'thence',
             'there',
             'thereafter',
             'thereby',
             'therefore',
             'therein',
             'thereupon',
             'these',
             'they',
             'third',
             'this',
             'thornton',
             'those',
             'though',
             'three',
             'through',
             'throughout',
             'thru',
             'thursday',
             'thus',
             'timor',
             'title',
             'tobago',
             'together',
             'togo',
             'tokelau',
             'tome',
             'tonga',
             'toward',
             'towards',
             'trinidad',
             'trinity',
             'tristan',
             'tuesday',
             'tunisia',
             'turkey',
             'turkmenistan',
             'turks',
             'tuvalu',
             'twelve',
             'twenty',
             'tyco',
             'uganda',
             'ukraine',
             'unauthorised',
             'unauthorized',
             'under',
             'united',
             'univar',
             'unless',
             'until',
             'upon',
             'uruguay',
             'used',
             'using',
             'uzbekistan',
             'valeant',
             'vanuatu',
             'various',
             'vatican',
             'venezuela',
             'verde',
             'very',
             'viatris',
             'viet',
             'vincent',
             'virgin',
             'votre',
             'vous',
             'wallis',
             'warner',
             'wasn',
             'wednesday',
             'well',
             'were',
             'weren',
             'western',
             'what',
             'whatever',
             'when',
             'whence',
             'whenever',
             'where',
             'whereafter',
             'whereas',
             'whereby',
             'wherein',
             'whereupon',
             'wherever',
             'whether',
             'which',
             'while',
             'whither',
             'whoever',
             'whole',
             'whom',
             'whose',
             'will',
             'with',
             'within',
             'without',
             'wockhardt',
             'would',
             'wouldn',
             'wyeth',
             'yamanouchi',
             'yemen',
             'your',
             'yours',
             'yourself',
             'yourselves',
             'zambia',
             'zealand',
             'zimbabwe'}
